# UIS Indicator Data API query examples

Documentation of the indicator data API endpoint: https://api.uis.unesco.org/api/public/documentation/operations/getIndicatorData

## Fetch all data records for a single indicator

This fetches all availble data for the indicator `CR.1`.

https://api.uis.unesco.org/api/public/data/indicators?indicator=CR.1

## Fetch all data records for a single indicator with footnotes & indicator metadata

This fetches all available data for the indicator `CR.1` and also returns footnotes (data point level metadata) as well as indicator metadata.

https://api.uis.unesco.org/api/public/data/indicators?indicator=CR.1&footnotes=true&indicatorMetadata=true

## Fetch all data records for a single country

This fetches all available indicator data for the country `BRA` (Brasil) including footnotes and indicator metadata.

https://api.uis.unesco.org/api/public/data/indicators?geoUnit=BRA

## Fetch data records for multiple indicators and countries

This fetches all available indicator data for the indicators `CR.1`, `CR.2` and `CR.3` for the countries `BRA`, `USA` and `DEU`.

https://api.uis.unesco.org/api/public/data/indicators?indicator=CR.1&indicator=CR.2&indicator=CR.3&geoUnit=BRA&geoUnit=USA&geoUnit=DEU

## Fetch data records for multiple indicators and countries and specific time range

This fetches all available indicator data for the indicators `CR.1`, `CR.2` and `CR.3` for the countries `BRA`, `USA` and `DEU`. The results are limited to the years between `2010` and `2015`.

https://api.uis.unesco.org/api/public/data/indicators?indicator=CR.1&indicator=CR.2&indicator=CR.3&geoUnit=BRA&geoUnit=USA&geoUnit=DEU&start=2010&end=2015

## Fetch data records for multiple indicators and countries and open ended time range

This fetches all available indicator data for the indicators `CR.1`, `CR.2` and `CR.3` for the countries `BRA`, `USA` and `DEU`. The results are limited to the years after `2010`.

https://api.uis.unesco.org/api/public/data/indicators?indicator=CR.1&indicator=CR.2&indicator=CR.2&geoUnit=BRA&geoUnit=USA&geoUnit=DEU&start=2010

## Single indicator only regional data

This fetches all available data for the indicator `CR.1` for regional geo units. The `geoUnitType` cannot be used in combination with a specific `geoUnit` as the `geoUnit` parameter will take precedence and the `geoUnitType` param will be ignored.

https://api.uis.unesco.org/api/public/data/indicators?indicator=CR.1&geoUnitType=REGIONAL

## Single indicator only national data

This fetches all available data for the indicator `CR.1` for national geo units. The `geoUnitType` cannot be used in combination with a specific `geoUnit` as the `geoUnit` parameter will take precedence and the `geoUnitType` param will be ignored.

https://api.uis.unesco.org/api/public/data/indicators?indicator=CR.1&geoUnitType=NATIONAL

## Examples with all parameters declared explicitly

### Multiple indicators and geo units including metadata and specific version

This fetches the data for the indicators `CR.1`, `CR.2` and `CR.3` for the countries `BRA`, `USA` and `DEU` for the years  between `2000` and `2010` including footnotes and indicator metadata for the specific version `20240910-b5ad4d82` (first published version).

https://api.uis.unesco.org/api/public/data/indicators?indicator=CR.1&indicator=CR.2&indicator=CR.3&geoUnit=BRA&geoUnit=USA&geoUnit=DEU&start=2000&end=2010&indicatorMetadata=true&footnotes=true&version=20240910-b5ad4d82

### Single indicator and country without metadata

This fetches the data for the indicators `CR.1` for the country `BRA` for the years between `2000` and `2010` without footnotes and indicator metadata and without specific version (always returns most current data).

https://api.uis.unesco.org/api/public/data/indicators?indicator=CR.1&geoUnit=BRA&start=2000&end=2010&indicatorMetadata=false&footnotes=false

## Example with invalid parameter values (indicator, geounit and start/end)

This query fetches data for the indicators `CR.1` and country `BRA` for the years `1900` to `1950`. The invalid indicator `CR2` and geoUnit `US` and ignored as they do not exists. The response also contains a hint, that no data exists for the given time range. This information is contained in the `hints` property of the API response.

https://api.uis.unesco.org/api/public/data/indicators?indicator=CR.1&indicator=CR2&geoUnit=BRA&geoUnit=US&start=1900&end=1950

## Example requesting too much data

This query tries to fetch more than 100 000 records and fails with an error message.

https://api.uis.unesco.org/api/public/data/indicators?geoUnit=BRA&geoUnit=USA&geoUnit=DEU&geoUnit=CHE